@@ -34,6 +34,7 @@
                             paropt="list", 
                             addfilename = "logical",
                             addest="vector", 
+                            adddataimage = "logical",
                             kinspecerr = "logical",
                             xlimspec = "vector",
                             ylimspec = "vector",
@@ -53,7 +54,10 @@
                             coldata = "vector",
                             ltyfit = "numeric",
                             ltydata = "numeric",
-                            optimmethod = "character"
+                            optimmethod = "character",
+                            parscale = "vector",
+                            maxfev = "numeric",
+                            imagepal = "vector"
 			), 
         prototype = list(
                         writecon = FALSE, 
@@ -71,35 +75,36 @@
                         minFactor = 1/1024,
                         plot = TRUE,
                         trilinear = FALSE,
-                        getStartTri = TRUE,
-                        triStart = list(),
-			addfilename = FALSE,
-			divdrel = TRUE, 
-			output = "ps", 
-			nnls = FALSE,
-			superimpose = vector(),
-			paropt = list(),
-			title = "",
-			makeps = "",
-			stderrclp = FALSE, 
-			summaryplotrow = 3, 
-			summaryplotcol = 4,
-			linrange = 1,
-			iter = 1, 
-			addest=vector(), 
-			kinspecerr = FALSE,
-			ylimspecplus = vector(), 
-			xlimspec = vector(),
-			ylimspec = vector(),
-                        xlim = vector(),
-			specinterpol = FALSE,
-			specinterpolpoints = TRUE, 
-			specinterpolseg = 50,
-			specinterpolbspline = FALSE,
-			normspec = FALSE,
-			writespecinterpol = FALSE, 
-			samespecline = FALSE,
-			nnlscrit = list(),
+          getStartTri = TRUE,
+          triStart = list(),
+          addfilename = FALSE,
+	  adddataimage = FALSE,
+          divdrel = TRUE, 
+          output = "ps", 
+          nnls = FALSE,
+          superimpose = vector(),
+          paropt = list(),
+          title = "",
+          makeps = "",
+          stderrclp = FALSE, 
+          summaryplotrow = 3, 
+          summaryplotcol = 4,
+          linrange = 1,
+          iter = 1, 
+          addest=vector(), 
+          kinspecerr = FALSE,
+          ylimspecplus = vector(), 
+          xlimspec = vector(),
+          ylimspec = vector(),
+          xlim = vector(),
+          specinterpol = FALSE,
+          specinterpolpoints = TRUE, 
+          specinterpolseg = 50,
+          specinterpolbspline = FALSE,
+          normspec = FALSE,
+          writespecinterpol = FALSE, 
+          samespecline = FALSE,
+          nnlscrit = list(),
           nlsalgorithm = "default",
           sumnls = TRUE,
           notraces = FALSE,
@@ -108,7 +113,10 @@
           coldata = vector(),
           ltyfit = numeric(),
           ltydata = numeric(),
-          optimmethod = "Nelder-Mead"
+          optimmethod = "Nelder-Mead",
+          parscale = vector(),
+          maxfev= 900,
+          imagepal = vector()
           ))
 
 setClass("kinopt", representation("opt",
@@ -119,7 +127,9 @@ setClass("kinopt", representation("opt",
                                   writerawcon = "logical",
                                   plotcohcolspec = "logical", 
                                   kinspecest = "logical",
-                                  writeplaincon = "list"),
+                                  writeplaincon = "list",
+                                  plotpulsefol = "logical",
+                                  ylimcomp = "vector"),
          prototype = list( 
            breakdown = list(),
            writerawcon = FALSE,
@@ -133,14 +143,16 @@ setClass("kinopt", representation("opt",
            xlab = "time",
            ylab = "wavelength",
            kinspecest = FALSE,
-           writeplaincon = list()))
+           writeplaincon = list(),
+           plotpulsefol = FALSE,
+           ylimcomp = vector()
+          ))
 
 setClass("massopt", representation("kinopt", axis.by = "numeric",
         scale.concen = "logical", nummaxtraces = "numeric"), prototype
         = list(normspec = TRUE, axis.by = 30, scale.concen = TRUE,
         nummaxtraces = 0) )
 
-
 setClass("specopt", representation("opt", nospectra = "logical",
 			   selectedspectra = "vector"), prototype =
 			   list( nospectra = FALSE, selectedspectra =
